==> better-admin-ui-vue-0.0.9.tgz: package/es/components/SearchTable/SearchTable.js <==
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * @Date: 2020/8/13 5:23 下午
 * @Author: Fioanna
 * @Description: 带搜索的列表
 */
import ESearchBar from '../SearchBar';
import SearchTableMixin from './SearchTable.mixin';
import searchTableProps from './types';
import AButton from 'ant-design-vue/es/button';
import ACard from 'ant-design-vue/es/card'; // 搜索条组件名称

var searchBarName = 'e-search-bar'; // 搜索条props名称列表

var searchPropKeyList = Object.keys(ESearchBar.props); // console.log('~~~searchPropKeyList~~~', searchPropKeyList)

var filterProps = function filterProps(props, filterFunc) {
  var res = {};

  for (var propsKey in props) {
    if (filterFunc(propsKey)) {
      res[propsKey] = props[propsKey];
    }
  }

  return res;
};

export default {
  name: 'ESearchTable',
  mixins: [SearchTableMixin],
  props: searchTableProps,
  computed: {
    searchProps: function searchProps() {
      if (this.$props.searchOptions) {
        return this.$props.searchOptions;
      } else {
        return filterProps(this.$props, function (key) {
          return searchPropKeyList.includes(key);
        });
      }
    },
    tableProps: function tableProps() {
      if (this.$props.tableOptions) {
        return this.$props.tableOptions;
      } else {
        return filterProps(this.$props, function (key) {
          return !searchPropKeyList.includes(key);
        });
      }
    },
    // 表格协议请求
    // loadList() {
    //   if (this.tableProps.data) {
    //     return parameter => {
    //       return this.tableProps.data(Object.assign({}, parameter, this.queryParam))
    //     }
    //   } else {
    //     return () => {
    //       return Promise.reject(new Error('获取数据失败'))
    //     }
    //   }
    // },
    // 表格配置
    tableConfigs: function tableConfigs() {
      return _extends({}, this.tableProps, {
        data: this.loadList
      });
    }
  },
  methods: {
    /**
     * 获取列表数据的协议，需重写
     * @param parameter
     */
    // eslint-disable-next-line
    getDataList: function getDataList(parameter) {
      return this.tableProps.data(_extends({}, parameter, this.queryParam));
    }
  },
  render: function render(createElement) {
    var _this = this;

    var tableCard = [];
    var tableCenterList = []; // 添加新增按钮

    if (this.$props.addText) {
      var addText = typeof this.$props.addText === 'string' ? this.$props.addText : '新增';
      tableCenterList.push(createElement(AButton, {
        props: {
          icon: 'plus',
          type: 'primary'
        },
        style: {
          marginBottom: '16px'
        },
        on: {
          click: function click() {
            _this.$emit('add');
          }
        }
      }, addText));
    } // 添加表格中间插槽


    if (this.$slots.tableCenter) {
      tableCenterList.push.apply(tableCenterList, _toConsumableArray(this.$slots.tableCenter));
    } // 如果中间有则新增一个div


    if (tableCenterList.length > 0) {
      tableCard.push(createElement('div', {
        "class": 'search-table-center-wrapper'
      }, tableCenterList));
    } // 插入表格


    tableCard.push(createElement(this.$props.tableName, {
      ref: 'table',
      props: this.tableConfigs,
      on: {
        expand: function expand(expanded, record) {
          _this.$emit('expand', expanded, record);
        }
      },
      scopedSlots: _objectSpread({}, this.$scopedSlots)
    }));
    return createElement('div', {}, [// 第一个子元素，搜索条
    createElement(searchBarName, {
      props: this.searchProps,
      on: {
        search: this._search,
        reset: function reset(formData) {
          _this.$emit('reset', formData);
        }
      }
    }), // 第二个子元素，表格
    createElement(ACard, {}, tableCard)]);
  }
};

==> better-admin-ui-vue-0.0.25.tgz: package/es/components/SearchTable/SearchTable.js <==
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * @Date: 2020/8/13 5:23 下午
 * @Author: Fioanna
 * @Description: 带搜索的列表
 */
import ESearchBar from '../SearchBar';
import SearchTableMixin from './SearchTable.mixin';
import searchTableProps from './types';
import AButton from 'ant-design-vue/es/button';
import ACard from 'ant-design-vue/es/card'; // 搜索条组件名称

var searchBarName = 'e-search-bar'; // 搜索条props名称列表

var searchPropKeyList = Object.keys(ESearchBar.props); // console.log('~~~searchPropKeyList~~~', searchPropKeyList)

var filterProps = function filterProps(props, filterFunc) {
  var res = {};

  for (var propsKey in props) {
    if (filterFunc(propsKey)) {
      res[propsKey] = props[propsKey];
    }
  }

  return res;
};

export default {
  name: 'ESearchTable',
  mixins: [SearchTableMixin],
  props: searchTableProps,
  computed: {
    searchProps: function searchProps() {
      if (this.$props.searchOptions) {
        return this.$props.searchOptions;
      } else {
        return filterProps(this.$props, function (key) {
          return searchPropKeyList.includes(key);
        });
      }
    },
    tableProps: function tableProps() {
      if (this.$props.tableOptions) {
        return this.$props.tableOptions;
      } else {
        return filterProps(this.$props, function (key) {
          return !searchPropKeyList.includes(key);
        });
      }
    },
    // 表格协议请求
    // loadList() {
    //   if (this.tableProps.data) {
    //     return parameter => {
    //       return this.tableProps.data(Object.assign({}, parameter, this.queryParam))
    //     }
    //   } else {
    //     return () => {
    //       return Promise.reject(new Error('获取数据失败'))
    //     }
    //   }
    // },
    // 表格配置
    tableConfigs: function tableConfigs() {
      return _extends({}, this.tableProps, {
        data: this.loadList
      });
    }
  },
  methods: {
    /**
     * 获取列表数据的协议，需重写
     * @param parameter
     */
    // eslint-disable-next-line
    getDataList: function getDataList(parameter) {
      return this.tableProps.data(_extends({}, parameter, this.queryParam));
    }
  },
  render: function render(createElement) {
    var _this = this;

    var tableCard = [];
    var tableCenterList = []; // 添加新增按钮

    if (this.$props.addText) {
      var addText = typeof this.$props.addText === 'string' ? this.$props.addText : '新增';
      tableCenterList.push(createElement(AButton, {
        props: {
          icon: 'plus',
          type: 'primary'
        },
        on: {
          click: function click() {
            _this.$emit('add');
          }
        }
      }, addText));
    } // 添加表格中间插槽


    if (this.$slots.tableCenter) {
      tableCenterList.push.apply(tableCenterList, _toConsumableArray(this.$slots.tableCenter));
    } // 如果中间有则新增一个div


    if (tableCenterList.length > 0) {
      tableCard.push(createElement('div', {
        "class": 'search-table-center-wrapper',
        style: {
          marginBottom: '16px'
        }
      }, tableCenterList));
    } // 插入表格


    tableCard.push(createElement(this.$props.tableName, {
      ref: 'table',
      props: this.tableConfigs,
      on: {
        expand: function expand(expanded, record) {
          _this.$emit('expand', expanded, record);
        }
      },
      scopedSlots: _objectSpread({}, this.$scopedSlots)
    }));
    return createElement('div', {}, [// 第一个子元素，搜索条
    createElement(searchBarName, {
      props: this.searchProps,
      on: {
        search: this._search,
        reset: function reset(formData) {
          _this.$emit('reset', formData);
        }
      }
    }), // 第二个子元素，表格
    createElement(ACard, {}, tableCard)]);
  }
};
